@@ -1,6 +1,6 @@
 #!@PERL@
 #
-# @(#)proc-messages.pl,v 1.40 2008/12/25 13:08:33 kim Exp
+# @(#)proc-messages.pl,v 1.41 2010/07/26 22:29:44 kim Exp
 #
 # Look through /var/adm/messages for things which might be errors (sorted
 # by machine) and put them on stdout.
@@ -685,6 +685,7 @@ sub skipimapd
     my ( $msg ) = @_;
     local ( $host );
 
+    return 1 if $msg =~ /^client id: /;
     return 1 if $msg =~ /^no user in db$/;
     return 1 if $msg =~ /^login:( \S+){2,3} (APOP|CRAM-MD5|PLAIN|plain(text)?)(\+TLS)?\s*(User logged in)?$/;
     return 1 if $msg =~ /^starttls: (SSL|TLS)v\d+ with cipher \S+ \(\d+\/\d+ bits( (new|reused))?\) no authentication\s*$/;
@@ -698,8 +699,15 @@ sub skipimapd
     return 1 if $msg =~ /^idle for too long, closing connection$/;
     return 1 if $msg =~ /^(DBERROR db3|DBMSG): \d+ lockers$/;
 
-    if ( $msg =~ /^badlogin: (\S+) \S+ authentication failure($| )/ ) {
-	$host = parsehost($1);
+    if ( $msg =~ /^badlogin: (\S+) (\S+) .+ authentication failure($|[: ].+)/ ) {
+	$host = parsehost("$1 $2");
+	if (defined($3)) {
+	    $msg = $3;
+	    if ( $msg =~ / realm changed($|:)/ ) {
+		$IMAP{"LOGIN FAILED: from $host (realm changed)\n"}++;
+		return 1;
+	    }
+	}
 	$IMAP{"LOGIN FAILED: from $host\n"}++;
 	return 1;
     }
@@ -1451,6 +1459,8 @@ sub skipcyrus
     # Cyrus 1.5.14 spells "elminated"
     return 1 if $msg =~ /^dupelim: eli?minated duplicate message to /;
 
+    return 1 if $msg =~ /^(DBERROR db3|DBMSG): \d+ lockers$/;
+
     return 0;
 }
 
